==> activity-center-api-0.9.24-xhw-20190627.075438-4-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ActivitySkinDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: ActivitySkinDataDto <br/>
 * Function: 活动皮肤Dto. <br/>
 * date: 2017年2月24日 下午2:54:49 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ActivitySkinDataDto extends BaseDto {

    private static final long serialVersionUID = -4872868154969983034L;

    public static final ActivitySkinDataDto EMPTY_DTO = new ActivitySkinDataDto(true);

    private Long              id;
    private Long              activityId;                              // 活动id
    private Integer           templateType;                            // 模板type <=> 活动类型
    private String            skinType;                                // 皮肤type
    private String            dataJson;
    private Integer           newLayerRate;                            // 新弹层占比
    private Long              aLayerId;                                // a弹层id
    private Long              bLayerId;                                // b弹层id

    private List<SkinLayerDto> layerList;

    public ActivitySkinDataDto() {

    }

    private ActivitySkinDataDto(boolean isEmpty) {
        super(isEmpty);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getDataJson() {
        return dataJson;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }

    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }
}

==> activity-center-api-0.9.55-xhw-20190821.023542-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/ActivitySkinDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: ActivitySkinDataDto <br/>
 * Function: 活动皮肤Dto. <br/>
 * date: 2017年2月24日 下午2:54:49 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class ActivitySkinDataDto extends BaseDto {

    private static final long serialVersionUID = -4872868154969983034L;

    public static final ActivitySkinDataDto EMPTY_DTO = new ActivitySkinDataDto(true);

    private Long              id;
    private Long              activityId;                              // 活动id
    private Integer           templateType;                            // 模板type <=> 活动类型
    private String            skinType;                                // 皮肤type
    private String            dataJson;
    private Integer           newLayerRate;                            // 新弹层占比
    private Long              aLayerId;                                // a弹层id
    private Long              bLayerId;                                // b弹层id

    private Integer           activitySkinType;                      //活动大类
    private Integer           activitySecondType;                    //活动小类

    private List<SkinLayerDto> layerList;

    public ActivitySkinDataDto() {

    }

    private ActivitySkinDataDto(boolean isEmpty) {
        super(isEmpty);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getDataJson() {
        return dataJson;
    }

    public void setDataJson(String dataJson) {
        this.dataJson = dataJson;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }

    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }

    public Integer getActivitySkinType() {
        return activitySkinType;
    }

    public void setActivitySkinType(Integer activitySkinType) {
        this.activitySkinType = activitySkinType;
    }

    public Integer getActivitySecondType() {
        return activitySecondType;
    }

    public void setActivitySecondType(Integer activitySecondType) {
        this.activitySecondType = activitySecondType;
    }
}
